==> kcm-fcitx_0.4.3.orig.tar.xz: kcm-fcitx-0.4.3/src/plugindialog.h <==
/***************************************************************************
 *   Copyright (C) 2013~2013 by CSSlayer                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.              *
 ***************************************************************************/
#ifndef PLUGINDIALOG_H
#define PLUGINDIALOG_H

#include <KDialog>
#include <fcitx-qt/fcitxqtconfiguiwidget.h>

namespace Fcitx {

class PluginDialog : public KDialog {
    Q_OBJECT
public:
    explicit PluginDialog(FcitxQtConfigUIWidget* widget, QWidget* parent = 0, Qt::WindowFlags flags = 0);
    virtual void slotButtonClicked(int button);

private:
    FcitxQtConfigUIWidget* m_widget;
public slots:
    void changed(bool changed);
    void saveFinished();
};

}

#endif // PLUGINDIALOG_H

==> kcm-fcitx_0.5.3.orig.tar.xz: kcm-fcitx-0.5.3/src/plugindialog.h <==
/***************************************************************************
 *   Copyright (C) 2013~2013 by CSSlayer                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.              *
 ***************************************************************************/
#ifndef PLUGINDIALOG_H
#define PLUGINDIALOG_H

#include <QDialog>
#include <QDialogButtonBox>
#include <fcitxqtconfiguiwidget.h>

namespace Fcitx {

class PluginDialog : public QDialog {
    Q_OBJECT
public:
    explicit PluginDialog(FcitxQtConfigUIWidget* widget, QWidget* parent = 0, Qt::WindowFlags flags = 0);
    virtual void slotButtonClicked(QDialogButtonBox::StandardButton button);

private:
    FcitxQtConfigUIWidget* m_widget;
    QDialogButtonBox* m_buttonBox;
public slots:
    void changed(bool changed);
    void saveFinished();
};

}

#endif // PLUGINDIALOG_H
